@@ -60,7 +60,9 @@ from ._data_structures import (
     TreeObject,
     read_object,
 )
+from ._files import EmbeddedFile
 from ._fit import Fit
+from ._link import DirectReferenceLink, NamedReferenceLink, ReferenceLink, extract_links
 from ._outline import OutlineItem
 from ._rectangle import RectangleObject
 from ._utils import (
@@ -85,7 +87,7 @@ class AnnotationBuilder:  # deprecated
     its usage combined with PdfWriter.
     """
 
-    from ..generic._rectangle import RectangleObject
+    from ..generic._rectangle import RectangleObject  # noqa: PLC0415
 
     @staticmethod
     def text(
@@ -182,7 +184,7 @@ class AnnotationBuilder:  # deprecated
             "AnnotationBuilder.polygon", "pypdf.annotations.Polygon", "5.0.0"
         )
 
-    from ._fit import DEFAULT_FIT
+    from ._fit import DEFAULT_FIT  # noqa: PLC0415
 
     @staticmethod
     def link(
@@ -198,45 +200,44 @@ class AnnotationBuilder:  # deprecated
 
 
 __all__ = [
-    # Base types
-    "BooleanObject",
-    "FloatObject",
-    "NumberObject",
-    "NameObject",
-    "IndirectObject",
-    "NullObject",
-    "PdfObject",
-    "TextStringObject",
-    "ByteStringObject",
-    # Annotations
-    "AnnotationBuilder",
-    # Fit
-    "Fit",
     "PAGE_FIT",
-    # Data structures
+    "AnnotationBuilder",
     "ArrayObject",
-    "DictionaryObject",
-    "TreeObject",
-    "StreamObject",
-    "DecodedStreamObject",
-    "EncodedStreamObject",
+    "BooleanObject",
+    "ByteStringObject",
     "ContentStream",
-    "RectangleObject",
-    "Field",
+    "DecodedStreamObject",
     "Destination",
-    "ViewerPreferences",
-    # --- More specific stuff
-    # Outline
-    "OutlineItem",
+    "DictionaryObject",
+    "DirectReferenceLink",
+    "EmbeddedFile",
+    "EncodedStreamObject",
+    "Field",
+    "Fit",
+    "FloatObject",
+    "IndirectObject",
+    "NameObject",
+    "NamedReferenceLink",
+    "NullObject",
+    "NumberObject",
     "OutlineFontFlag",
-    # Data structures core functions
-    "read_object",
+    "OutlineItem",
+    "PdfObject",
+    "RectangleObject",
+    "ReferenceLink",
+    "StreamObject",
+    "TextStringObject",
+    "TreeObject",
+    "ViewerPreferences",
     # Utility functions
     "create_string_object",
-    "encode_pdfdocencoding",
     "decode_pdfdocencoding",
+    "encode_pdfdocencoding",
+    "extract_links",
     "hex_to_rgb",
     "is_null_or_none",
     "read_hex_string_from_stream",
+    # Data structures core functions
+    "read_object",
     "read_string_from_stream",
 ]
